summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorDevang Patel <dpatel@apple.com>2008-09-24 00:29:49 +0000
committerDevang Patel <dpatel@apple.com>2008-09-24 00:29:49 +0000
commit1e480009662c4ec56e16fc5b44fb9affef98bcbc (patch)
treeb4f6198f95c60a428292623224ec4941d572b728 /include
parent3d84a76917c4bb1e4d5b99009a7fb32970fb20b8 (diff)
downloadexternal_llvm-1e480009662c4ec56e16fc5b44fb9affef98bcbc.zip
external_llvm-1e480009662c4ec56e16fc5b44fb9affef98bcbc.tar.gz
external_llvm-1e480009662c4ec56e16fc5b44fb9affef98bcbc.tar.bz2
s/ParamAttributeListImpl/AttributeListImpl/g
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@56532 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/Attributes.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/llvm/Attributes.h b/include/llvm/Attributes.h
index 0e41694..7e464ba 100644
--- a/include/llvm/Attributes.h
+++ b/include/llvm/Attributes.h
@@ -105,14 +105,14 @@ struct ParamAttrsWithIndex {
// PAListPtr Smart Pointer
//===----------------------------------------------------------------------===//
-class ParamAttributeListImpl;
+class AttributeListImpl;
/// PAListPtr - This class manages the ref count for the opaque
/// ParamAttributeListImpl object and provides accessors for it.
class PAListPtr {
/// PAList - The parameter attributes that we are managing. This can be null
/// to represent the empty parameter attributes list.
- ParamAttributeListImpl *PAList;
+ AttributeListImpl *PAList;
public:
PAListPtr() : PAList(0) {}
PAListPtr(const PAListPtr &P);
@@ -204,7 +204,7 @@ public:
const ParamAttrsWithIndex &getSlot(unsigned Slot) const;
private:
- explicit PAListPtr(ParamAttributeListImpl *L);
+ explicit PAListPtr(AttributeListImpl *L);
};
} // End llvm namespace
@@ -105,14 +105,14 @@ struct ParamAttrsWithIndex {
/// PAListPtr - This class manages the ref count for the opaque
-/// ParamAttributeListImpl object and provides accessors for it.
+/// AttributeListImpl object and provides accessors for it.
class PAListPtr {
/// PAList - The parameter attributes that we are managing. This can be null